==> synimport-8.x-1.54.tar.gz: synimport/src/Drush/DrushContentImport.php <==
<?php

namespace Drupal\synimport\Drush;

use Drush\Commands\DrushCommands;
use Drupal\synimport\Service\Import;
use Drupal\synimport\Service\Logger;
use Drupal\synimport\Utility\EmptyDirException;

/**
 * A Drush commandfile.
 */
class DrushContentImport extends DrushCommands {
  /**
   * Logger variable.
   *
   * @var Logger
   */
  protected $log;

  /**
   * Import Service variable.
   *
   * @var Import
   */
  protected $synimport;

  /**
   * Command constructor.
   *
   * @param Logger $logger
   * @param Import $synimport
   */
  public function __construct(Logger $logger, Import $synimport) {
    $this->log = $logger;
    $this->synimport = $synimport;
  }

  /**
   * Synapse Content import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport
   *   Full import from $directory.
   */
  public function import($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->import($directory);
  }

  /**
   * Synapse Contacts import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:contacts
   *   Contacts import from $directory.
   */
  public function importContacts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importContacts($directory);
  }

  /**
   * Synapse Taxonomy import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:taxonomy
   *   Taxonomy import from $directory.
   */
  public function importTaxonomy($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importTaxonomy($directory);
  }

  /**
   * Synapse Nodes import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:node
   *   Nodes import from $directory.
   */
  public function importNode($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importNode($directory);
  }

  /**
   * Synapse Menu import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:menu
   *   Menu import from $directory.
   */
  public function importMenu($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importMenu($directory);
  }

  /**
   * Synapse Products import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:product
   *   Products import from $directory.
   */
  public function importProducts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importProducts($directory);
  }

  /**
   * Synapse Blocks import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:block
   *   Blocks import from $directory.
   */
  public function importBlocks($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importBlocks($directory);
  }

  /**
   * Synapse Synlanding Config import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:synlanding_config
   *   Synlanding Config import from $directory.
   */
  public function setSynlandingFormBg($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setSynlandingFormBg($directory);
  }

  /**
   * Check for empty directory.
   *
   * @throws EmptyDirException
   *
   *   No file input.
   */
  private function dirIsEmpty($dirname) {
    if (!file_exists($dirname)) {
      $this->log->send("Not a valid path $dirname");
      throw new EmptyDirException("Not a valid path $dirname");
    }
    if (!is_dir($dirname)) {
      $this->log->send("Not a directory $dirname");
      throw new EmptyDirException("Not a directory $dirname");
    }
    foreach (scandir($dirname) as $file) {
      if (!in_array($file, ['.', '..', '.svn', '.git'])) {
        return FALSE;
      }
    }
    $this->log->send("Dir is empty $dirname");
    throw new EmptyDirException("Dir is empty $dirname");
  }

}

==> synimport-8.x-1.56.tar.gz: synimport/src/Drush/DrushContentImport.php <==
<?php

namespace Drupal\synimport\Drush;

use Drush\Commands\DrushCommands;
use Drupal\synimport\Service\Import;
use Drupal\synimport\Service\Logger;
use Drupal\synimport\Utility\EmptyDirException;

/**
 * A Drush commandfile.
 */
class DrushContentImport extends DrushCommands {
  /**
   * Logger variable.
   *
   * @var Logger
   */
  protected $log;

  /**
   * Import Service variable.
   *
   * @var Import
   */
  protected $synimport;

  /**
   * Command constructor.
   *
   * @param Logger $log
   * @param Import $synimport
   */
  public function __construct(Logger $log, Import $synimport) {
    $this->log = $log;
    $this->synimport = $synimport;
  }

  /**
   * Synapse Content import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport
   *   Full import from $directory.
   */
  public function import($directory) {
    $this->dirIsEmpty($directory);
    $this->log->log('222');
    $this->synimport->setLogger($this->log);
    $this->synimport->import($directory);
  }

  /**
   * Synapse Contacts import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:contacts
   *   Contacts import from $directory.
   */
  public function importContacts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->importContacts($directory);
  }

  /**
   * Synapse Taxonomy import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:taxonomy
   *   Taxonomy import from $directory.
   */
  public function importTaxonomy($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importTaxonomy($directory);
  }

  /**
   * Synapse Nodes import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:node
   *   Nodes import from $directory.
   */
  public function importNode($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importNode($directory);
  }

  /**
   * Synapse Menu import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:menu
   *   Menu import from $directory.
   */
  public function importMenu($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importMenu($directory);
  }

  /**
   * Synapse Products import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:product
   *   Products import from $directory.
   */
  public function importProducts($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importProducts($directory);
  }

  /**
   * Synapse Blocks import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:block
   *   Blocks import from $directory.
   */
  public function importBlocks($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setLogger($this->log);
    $this->synimport->importBlocks($directory);
  }

  /**
   * Synapse Synlanding Config import.
   *
   * @param string $directory
   *   Content directory.
   *
   * @command synimport:synlanding_config
   *   Synlanding Config import from $directory.
   */
  public function setSynlandingFormBg($directory) {
    $this->dirIsEmpty($directory);
    $this->synimport->setSynlandingFormBg($directory);
  }

  /**
   * Check for empty directory.
   *
   * @throws EmptyDirException
   *
   *   No file input.
   */
  private function dirIsEmpty($dirname) {
    if (!file_exists($dirname)) {
      $this->log->send("Not a valid path $dirname");
      throw new EmptyDirException("Not a valid path $dirname");
    }
    if (!is_dir($dirname)) {
      $this->log->send("Not a directory $dirname");
      throw new EmptyDirException("Not a directory $dirname");
    }
    foreach (scandir($dirname) as $file) {
      if (!in_array($file, ['.', '..', '.svn', '.git'])) {
        return FALSE;
      }
    }
    $this->log->send("Dir is empty $dirname");
    throw new EmptyDirException("Dir is empty $dirname");
  }

}
